==> customer-js-sdk-1.4.0.tgz: package/src/v0/src/helpers/request.js <==
import { makeRequest } from 'sling-helpers';

import { get as getBaseUrl } from '../services/baseUrl.js';
import { get as getHeader } from '../services/headers.js';
import { validateRequiredParams } from './validateRequiredParams.js';
import { validateBaseUrl } from './validateBaseUrl.js';
import { validatePayload } from './validatePayload.js';

import { GET, POST, PUT, PATCH } from '../constants/constants.js';

export const request =
  (urlMaker, method = GET, requestInterface = {}, fetchMaker = makeRequest) =>
    (...args) => {
      try {
        const [urlParams, payload = {}] =
          args.filter(arg => typeof arg === 'object');

        const customBaseUrl =
          args.find(arg => typeof arg === 'string') || getBaseUrl();

        const resource = validateBaseUrl(customBaseUrl);

        const url = (typeof urlMaker === 'function')
          ? urlMaker(urlParams)
          : urlMaker || '';

        const validUrl = validateRequiredParams(`${resource}${url}`);

        let requestParams = {
          method,
          headers: getHeader(),
        };

        if (Object.keys(payload).length > 0) {
          requestParams = {
            ...requestParams,
            body: validatePayload(requestInterface, payload, method),
          };
        }

        return fetchMaker(validUrl, requestParams);
      } catch (err) {
        return Promise.reject(err);
      }
    };

export const getRequest = (urlMaker, fetchMaker) =>
  request(urlMaker, GET, fetchMaker);

export const postRequest = (urlMaker, requestInterface, fetchMaker) =>
  request(urlMaker, POST, requestInterface, fetchMaker);

export const putRequest = (urlMaker, requestInterface, fetchMaker) =>
  request(urlMaker, PUT, requestInterface, fetchMaker);

export const patchRequest = (urlMaker, requestInterface, fetchMaker) =>
  request(urlMaker, PATCH, requestInterface, fetchMaker);

==> customer-js-sdk-1.13.0.tgz: package/src/v0/src/helpers/request.js <==
import { makeRequest } from './makeRequest.js';

import { get as getBaseUrl } from '../services/baseUrl.js';
import { get as getHeader } from '../services/headers.js';
import { validateRequiredParams } from './validateRequiredParams.js';
import { validateBaseUrl } from './validateBaseUrl.js';
import { validatePayload } from './validatePayload.js';

import { GET, POST, PUT, PATCH } from '../constants/constants.js';

export const request =
  (urlMaker, method = GET, requestInterface = {}, fetchMaker = makeRequest) =>
    (...args) => {
      try {
        const [urlParams = {}, payload = {}] =
          args.filter(arg => typeof arg === 'object');

        const customBaseUrl =
          args.find(arg => typeof arg === 'string') || getBaseUrl();

        const resource = validateBaseUrl(customBaseUrl);

        const url = (typeof urlMaker === 'function')
          ? urlMaker(urlParams)
          : urlMaker || '';

        const validUrl = validateRequiredParams(`${resource}${url}`);

        let requestParams = {
          method,
          headers: getHeader(),
        };

        if (Object.keys(payload).length > 0) {
          requestParams = {
            ...requestParams,
            body: validatePayload(requestInterface, payload, method),
          };
        }

        return fetchMaker(validUrl, requestParams);
      } catch (err) {
        return Promise.reject(err);
      }
    };

export const getRequest = (urlMaker, fetchMaker) =>
  request(urlMaker, GET, fetchMaker);

export const postRequest = (urlMaker, requestInterface, fetchMaker) =>
  request(urlMaker, POST, requestInterface, fetchMaker);

export const putRequest = (urlMaker, requestInterface, fetchMaker) =>
  request(urlMaker, PUT, requestInterface, fetchMaker);

export const patchRequest = (urlMaker, requestInterface, fetchMaker) =>
  request(urlMaker, PATCH, requestInterface, fetchMaker);
